# omni-belt

[![Unit-Tests](https://github.com/felixludos/omni-belt/actions/workflows/tests.yaml/badge.svg)](https://github.com/felixludos/omni-belt/actions/workflows/tests.yaml)


This is a simple tool belt containing pure python utilities for downstream projects.

Note: This package is still very much under development, so keep a close eye on the version number, 
as I cannot make any promises about forward or backward compatibility (at least until version 1.0). Additionally, 
by my estimates about a fourth of the code in this repo is either partially or completely obsolete, 
and will be removed in the near future.

While there are some unit tests (see badge above for status), they are far from comprehensive, 
and documentation is spotty at best.

## Related Projects

- [omni-fig](https://github.com/felixludos/omni-fig): A versatile configuration management (fully documented and maintained)
- [omni-crypt](https://github.com/felixludos/omni-crypt): A handful of simple cryptographic utilities (under development)
